@@ -1,7 +1,10 @@
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 def run(code):
   file = open("code.py", "w+")
   file.write(code)
   file.close()
   exec(open("code.py").read())
+
+def write(text):
+  print(text)
\ No newline at end of file
